==> cramr_ui_lib-1.0.13.tar.gz: test/routes/repeat_selection_route_test.dart <==
import 'dart:convert';

import 'package:cramr_ui_lib/ads/ads_controller.dart';
import 'package:cramr_ui_lib/ads/safe_banner_ad_widget.dart';
import 'package:cramr_ui_lib/model/practice_session.dart';
import 'package:cramr_ui_lib/model/streak_engine.dart';
import 'package:cramr_ui_lib/routes/repeat_selection_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';
final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

void main() {
  group('test functionality when having no practice sessions available', () {
    testWidgets('find button and text', (WidgetTester tester) async {
      SharedPreferences prefs = await initPrefs(true);
      SettingsController controller =
          SettingsController(SettingsService(prefs), ThemeMode.dark, prefs);
      MaterialApp app = await createMaterialApp(prefs, controller);
      AdsController? adsController = AdsController(MobileAds.instance);
      await tester.pumpWidget(MultiProvider(providers: [
        Provider<AdsController?>(
          create: (BuildContext context) {
            return adsController;
          },
        )
      ], child: app));
      Finder nothingFoundTextFinder =
          find.text('Je hebt nog geen werkwoorden om te herhalen');
      Finder somethingNewTextFinder = find.text('Leer iets nieuws');
      expect(nothingFoundTextFinder, findsOneWidget);
      expect(somethingNewTextFinder, findsOneWidget);
    });
  });
  group('test functionality when having practice sessions available', () {
    testWidgets('test for existing sessions with infinitives',
        (WidgetTester tester) async {
      SharedPreferences prefs = await initPrefs(true);
      SettingsController controller =
          SettingsController(SettingsService(prefs), ThemeMode.dark, prefs);
      MaterialApp app = await createMaterialApp(prefs, controller);
      controller.streakEngine.addSession(PracticeSession(
          DateTime.now(),
          _mode,
          _tense,
          _randomIndicative,
          StudyMethod.coverMethod,
          _randomInfinitive));
      AdsController? adsController = AdsController(MobileAds.instance);
      await tester.pumpWidget(MultiProvider(providers: [
        Provider<AdsController?>(
          create: (BuildContext context) {
            return adsController;
          },
        )
      ], child: app));
      Finder nothingFoundTextFinder =
          find.text('Je hebt nog geen werkwoorden om te herhalen');
      Finder somethingNewTextFinder = find.text('Leer iets nieuws');
      expect(nothingFoundTextFinder, findsNothing);
      expect(somethingNewTextFinder, findsNothing);
    });
  });
}

Future<MaterialApp> createMaterialApp(
    SharedPreferences prefs, SettingsController controller) async {
  await controller.loadSettings();
  return MaterialApp(
    home: RepeatSelectionRoute(
      safeBannerAdWidget: const SafeBannerAdWidget(
        adUnitId: '',
        adRequest: AdRequest(),
      ),
      settingsController: controller,
    ),
  );
}

Future<SharedPreferences> initPrefs(bool hasNoSessions) async {
  StreakEngine engine = StreakEngine();
  if (!hasNoSessions) {
    engine.addSession(PracticeSession(DateTime.now(), _mode, _tense,
        _randomIndicative, StudyMethod.coverMethod, _randomInfinitive));
    engine.addSession(PracticeSession(DateTime.now(), _mode, _tense,
        _randomIndicative, StudyMethod.coverMethod, _randomInfinitive));
  }
  SharedPreferences.setMockInitialValues(
      <String, Object>{'counter': 1, 'streakEngine': jsonEncode(engine)});
  SharedPreferences prefs = await SharedPreferences.getInstance();
  return prefs;
}

==> cramr_ui_lib-1.0.14.tar.gz: test/routes/repeat_selection_route_test.dart <==
import 'dart:convert';

import 'package:cramr_ui_lib/ads/ads_controller.dart';
import 'package:cramr_ui_lib/ads/safe_banner_ad_widget.dart';
import 'package:cramr_ui_lib/model/cardinality_selection.dart';
import 'package:cramr_ui_lib/model/practice_session.dart';
import 'package:cramr_ui_lib/model/streak_engine.dart';
import 'package:cramr_ui_lib/routes/repeat_selection_route.dart';
import 'package:cramr_ui_lib/settings/notification_service.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';
final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

void main() {
  group('test functionality when having no practice sessions available', () {
    testWidgets('find button and text', (WidgetTester tester) async {
      SharedPreferences prefs = await initPrefs(true);
      SettingsController controller = SettingsController(
          SettingsService(prefs), ThemeMode.dark, prefs, NotificationService());
      MaterialApp app = await createMaterialApp(prefs, controller);
      AdsController? adsController = AdsController(MobileAds.instance);
      await tester.pumpWidget(MultiProvider(providers: [
        Provider<AdsController?>(
          create: (BuildContext context) {
            return adsController;
          },
        )
      ], child: app));
      Finder nothingFoundTextFinder =
          find.text('Je hebt nog geen werkwoorden om te herhalen');
      Finder somethingNewTextFinder = find.text('Leer iets nieuws');
      expect(nothingFoundTextFinder, findsOneWidget);
      expect(somethingNewTextFinder, findsOneWidget);
    });
  });
  group('test functionality when having practice sessions available', () {
    testWidgets('test for existing sessions with infinitives',
        (WidgetTester tester) async {
      SharedPreferences prefs = await initPrefs(true);
      SettingsController controller = SettingsController(
          SettingsService(prefs), ThemeMode.dark, prefs, NotificationService());
      MaterialApp app = await createMaterialApp(prefs, controller);
      controller.streakEngine.addSession(PracticeSession(
          DateTime.now(),
          _mode,
          _tense,
          _randomIndicative,
          StudyMethod.coverMethod,
          _randomInfinitive));
      AdsController? adsController = AdsController(MobileAds.instance);
      await tester.pumpWidget(MultiProvider(providers: [
        Provider<AdsController?>(
          create: (BuildContext context) {
            return adsController;
          },
        )
      ], child: app));
      Finder nothingFoundTextFinder =
          find.text('Je hebt nog geen werkwoorden om te herhalen');
      Finder somethingNewTextFinder = find.text('Leer iets nieuws');
      expect(nothingFoundTextFinder, findsNothing);
      expect(somethingNewTextFinder, findsNothing);
    });
  });
}

Future<MaterialApp> createMaterialApp(
    SharedPreferences prefs, SettingsController controller) async {
  await controller.loadSettings();
  return MaterialApp(
    home: RepeatSelectionRoute(
      safeBannerAdWidget: const SafeBannerAdWidget(
        adUnitId: '',
        adRequest: AdRequest(),
      ),
      settingsController: controller,
    ),
  );
}

Future<SharedPreferences> initPrefs(bool hasNoSessions) async {
  StreakEngine engine = StreakEngine();
  if (!hasNoSessions) {
    engine.addSession(PracticeSession(DateTime.now(), _mode, _tense,
        _randomIndicative, StudyMethod.coverMethod, _randomInfinitive));
    engine.addSession(PracticeSession(DateTime.now(), _mode, _tense,
        _randomIndicative, StudyMethod.coverMethod, _randomInfinitive));
  }
  SharedPreferences.setMockInitialValues(
      <String, Object>{'counter': 1, 'streakEngine': jsonEncode(engine)});
  SharedPreferences prefs = await SharedPreferences.getInstance();
  return prefs;
}
